# Autogenerated by Astropy's setup.py on 2018-12-31 23:55:33 UTC
from __future__ import unicode_literals
import datetime

version = "3.1.1"
githash = "63355d3d334b7d8c05cd517a8edfaca07ccfb65b"


major = 3
minor = 1
bugfix = 1

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2018, 12, 31, 23, 55, 33)
debug = False

astropy_helpers_version = "3.1"

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
